/*
		GNU GENERAL PUBLIC LICENSE
		Version 3, 29 June 2007


kyoketsu, a Client-To-Client Network Enumeration System
Copyright (C) 2024 Russell Hrubesky, ChiralWorks Software LLC

 Copyright (C) 2007 Free Software Foundation, Inc. <https://fsf.org/>
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

package main

import (
	"database/sql"
	"fmt"
	"log"
	"os"
	"sync"

	kyoketsu "git.aetherial.dev/aeth/kyoketsu/pkg"
)

const dbfile = "sqlite.db"

func main() {
	os.Remove(dbfile) // TODO: remove this once i add more smart interaction with the DB
	db, err := sql.Open("sqlite3", dbfile)
	if err != nil {
		log.Fatal(err)
	}

	hostsRepo := kyoketsu.NewSQLiteRepo(db)
	var wg sync.WaitGroup
	wg.Add(1)
	go kyoketsu.RunHttpServer(8082, hostsRepo)

	if err = hostsRepo.Migrate(); err != nil {
		log.Fatal(err)
	}
	log.Println("SUCCESS ::: SQLite database initiated, and open for writing.")

	hosts, err := kyoketsu.NetSweep(os.Args[1], kyoketsu.RetrieveScanDirectives().Pairs)
	if err != nil {
		log.Fatal(err)
	}
	for i := range hosts {
		fmt.Printf("%+v\n", hosts[i])
		_, err := hostsRepo.Create(*hosts[i])
		if err != nil {
			log.Fatalf("Couldnt create new entry :( error: %s\n", err)

		}

	}
	wg.Wait()

}
